aboutsummaryrefslogtreecommitdiff
path: root/src/dotty/tools/dotc/core/Types.scala
diff options
context:
space:
mode:
authorMartin Odersky <odersky@gmail.com>2013-02-28 15:03:45 +0100
committerMartin Odersky <odersky@gmail.com>2013-02-28 15:03:45 +0100
commitfe8ee1143f7aabc57212506b3bdd10d7abb63d67 (patch)
tree915b8a6d3c4cb19134b56285670d9e3dca5ca1b6 /src/dotty/tools/dotc/core/Types.scala
parente2d8e2acf76472a2c9b60048be8260e1d73435ac (diff)
downloaddotty-fe8ee1143f7aabc57212506b3bdd10d7abb63d67.tar.gz
dotty-fe8ee1143f7aabc57212506b3bdd10d7abb63d67.tar.bz2
dotty-fe8ee1143f7aabc57212506b3bdd10d7abb63d67.zip
more docs.
Plus renamed NullSignature -> NotAMethod
Diffstat (limited to 'src/dotty/tools/dotc/core/Types.scala')
-rw-r--r--src/dotty/tools/dotc/core/Types.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/dotty/tools/dotc/core/Types.scala b/src/dotty/tools/dotc/core/Types.scala
index a5fa211ec..e52b9dd17 100644
--- a/src/dotty/tools/dotc/core/Types.scala
+++ b/src/dotty/tools/dotc/core/Types.scala
@@ -475,13 +475,13 @@ object Types {
(pre eq cls.thisType)) this
else ctx.asSeenFrom(this, pre, cls, null)
/** The signature of this type. This is by default NullSignature,
* but is overridden for PolyTypes, MethodTypes, and TermRefWithSignature types.
* (the reason why we deviate from the "final-method-with-pattern-match-in-base-class"
* pattern is that method signatures use caching, so encapsulation
* is improved using an OO scheme).
*/
- def signature(implicit ctx: Context): Signature = NullSignature
+ def signature(implicit ctx: Context): Signature = NotAMethod
final def baseType(base: Symbol)(implicit ctx: Context): Type = base.denot match {
case classd: ClassDenotation => classd.baseTypeOf(this)
@@ -475,13 +475,13 @@ object Types {
(pre eq cls.thisType)) this
else ctx.asSeenFrom(this, pre, cls, null)
- /** The signature of this type. This is by default NullSignature,
+ /** The signature of this type. This is by default NotAMethod,
* but is overridden for PolyTypes, MethodTypes, and TermRefWithSignature types.
* (the reason why we deviate from the "final-method-with-pattern-match-in-base-class"